@@ -12,7 +12,7 @@ use JSON;
 use LWP::UserAgent;
 use List::Util qw(none);
 
-our $VERSION = '1.60.4';
+our $VERSION = '1.02';
 
 use parent qw(Class::Accessor::Fast);
 
@@ -20,7 +20,6 @@ __PACKAGE__->follow_best_practice;
 
 __PACKAGE__->mk_accessors(
   qw(
-    body
     css
     engine
     git_email
@@ -31,6 +30,7 @@ __PACKAGE__->mk_accessors(
     mode
     no_title
     raw
+    body
     render
     title
   )
@@ -55,7 +55,7 @@ sub new {
   my %options = ref $args[0] ? %{ $args[0] } : @args;
 
   $options{title}  //= $TOC_TITLE;
-  $options{css}    //= $options{nocss} ? $EMPTY : $DEFAULT_CSS;
+  $options{css}    //= $DEFAULT_CSS;
   $options{mode}   //= 'markdown';
   $options{engine} //= 'github';
 
@@ -181,21 +181,22 @@ sub _render_with_text_markdown {
 ########################################################################
   my ($self) = @_;
 
-  eval { require Text::Markdown::Discount; };
+  eval { require Text::Markdown; };
 
   if ($EVAL_ERROR) {
-    carp "no Text::Markdown::Discount available...using GitHub API.\n$EVAL_ERROR";
-    return $self->_render_with_github;
+    croak "no Text::Markdown available...try using GitHub API.\n$EVAL_ERROR";
   }
 
+  my $tm = Text::Markdown->new( trust_list_start_value => 1 );
+
   my $markdown = $self->get_markdown;
-  my $html     = Text::Markdown::Discount::markdown($markdown);
+  my $html     = Text::Markdown::markdown($markdown);
 
   if ( $self->get_raw ) {
     $self->set_html($html);
   }
   else {
-    $self->fix_anchors( Text::Markdown::Discount::markdown($markdown) );
+    $self->fix_anchors( Text::Markdown::markdown($markdown) );
   }
 
   return $self;
@@ -210,14 +211,10 @@ sub fix_anchors {
 
   my $html;
 
-  # sample:
-  # <div class="markdown-heading"><h1 class="heading-element">Table of Contents</h1><a id="table-of-contents" class="anchor" aria-label="Permalink: Table of Contents" href="#table-of-contents"><span aria-hidden="true" class="octicon octicon-link"></span></a></div>
-
   while ( my $line = <$fh> ) {
     # remove garbage if there...
-
-    if ( $line =~ m{<h(\d+)([^>]*?)>([^<]+?)</h\d+><a(.*?)/a>(.*?)}xsm ) {
-      $line = "<a$4$5/a><h$1$2>$3</h$1>\n";
+    if ( $line =~ /^\s*<h(\d+)><a (.*)>(.*)<\/a>(.*)/xsm ) {
+      $line = "<h$1>$3$4</h$1>\n";
     }
 
     $html .= _fix_header($line);
@@ -241,12 +238,13 @@ sub _fix_header {
 
   $anchor = lc $anchor;
   $anchor =~ s/\s+/-/gxsm;                        # spaces become '-'
-  $anchor =~ s/[.:\?_.\@'(),\`]//xsmg;            # known weird characters, but expect more
+  $anchor =~ s/[\@'(),\`]//xsmg;                  # known weird characters, but expect more
   $anchor =~ s/\///xsmg;
 
   $line
-    = sprintf qq{<a id="%s" class="anchor" href="#%s"></a><h%s>%s</h%d>\n},
-    $anchor, $anchor, $hn, $header, $hn;
+    = sprintf qq{<h%d><a id="%s" class="anchor" href="#%s"></a>%s</h%d>\n},
+    $hn,
+    $anchor, $anchor, $header, $hn;
 
   return $line;
 }
@@ -305,8 +303,7 @@ sub _render_with_github {
     return $self->fix_anchors( $rsp->content );
   }
   else {
-    $self->fix_anchors( $rsp->content );
-    return $self->fix_github_html( $self->get_html );
+    return $self->fix_github_html( $rsp->content );
   }
 }
 
@@ -376,7 +373,7 @@ sub create_toc {
 
       $link =~ s/\s+/-/gxsm;  # spaces become '-'
 
-      $link =~ s/[\?\_:.\@'(),\`]//xsmg;  # known weird characters, but expect more
+      $link =~ s/[\@'(),\`]//xsmg;  # known weird characters, but expect more
 
       $link =~ s/\///xsmg;
 
@@ -481,35 +478,12 @@ Markdown::Render - Render markdown as HTML
 
  $md->render_markdown->print_html;
 
-...or from the command line to create HTML
-
- md-utils.pl -r README.md > README.html
-
-...or from the command line to replace render custom tags
-
- md-utils.pl README.md.in > README.md
-
 =head1 DESCRIPTION
 
-Renders markdown as HTML using either GitHub's API or
-L<Text::Markdown::Discount>. Optionally adds additional metadata to markdown
-document using custom tags.
+Renders markdown as HTML using either GitHub's API or L<Text::Markdown>. Optionally adds
+additional metadata to markdown document using custom tags.
 
-See
-L<README.md|https://github.com/rlauer6/markdown-utils/blob/master/README.md>
-for more details.
-
-I<Note: This module originally used L<Text::Markdown> as an
-alternative to using the GitHub API however, there are too many bugs
-and idiosyncracies in that module. This module will now use
-L<Text::Markdown::Discount> which is not only faster, but seems to be
-more compliant with GFM.>
-
-I<Note: Text::Markdown::Discount relies on the text-markdown library
-which did not actually support all of the markdown features (including
-code fencing).  You can find an updated version of
-L<Text::Markdown::Discount> here:
-L<https://github.com/rlauer6/text-markdown-discount>>
+See L<README.md|https://github.com/rlauer6/markdown-utils/blob/master/README.md> for more details.
 
 =head1 METHODS AND SUBROUTINES
 
@@ -538,7 +512,7 @@ Name of the git user that is used in the C<GIT_USER> tag.
 
 =item git_email
 
-Email address of the git user that is used in the C<GIT_EMAIL> tag.
+Email address of the git user is used in the C<GIT_EMAIL> tag.
 
 =item infile
 
@@ -556,8 +530,7 @@ default: markdown
 
 =item no_title
 
-Boolean that indicates that no title should be added to the table of
-contents.
+Boolean that indicates that no title should be added to the table of contents.
 
 default: false
 
@@ -599,7 +572,7 @@ Outputs the fully rendered HTML page.
 URL of a CSS style sheet to include in the head section. If no CSS
 file option is passed a default CSS file will b used. If a CSS element
 is passed but it is undefined or empty, then no CSS will be specified
-in the final document.
+i the final document.
 
 =item title
 
@@ -612,11 +585,10 @@ will be added to the document.
 
 =head1 AUTHOR
 
-Rob Lauer - rlauer6@comcast.net
+Rob Lauer - rclauer@gmail.com
 
 =head1 SEE OTHER
 
 L<GitHub Markdown API|https://docs.github.com/en/rest/markdown>
-L<Text::Markdown::Discount>
 
 =cut
